===
API
===

Indices
=======

.. toctree::

   indices

Indices submodules
------------------


.. automodule:: xclim.indices.generic
   :noindex:
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: xclim.indices.run_length
   :noindex:
   :members:
   :undoc-members:
   :show-inheritance:

Indicator tools
===============

.. automodule:: xclim.core.indicator
   :noindex:
   :members:
   :member-order: bysource
   :show-inheritance:


Unit handling module
====================

.. automodule:: xclim.core.units
   :noindex:
   :members:
   :undoc-members:
   :show-inheritance:


.. toctree::

     sdba_api


Other utilities
===============

.. automodule:: xclim.core.calendar
   :noindex:
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: xclim.core.checks
   :noindex:
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: xclim.core.formatting
   :noindex:
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: xclim.core.utils
   :noindex:
   :members:
   :undoc-members:
   :show-inheritance:


Other xclim modules
===================

ensembles module
----------------

.. automodule:: xclim.ensembles
   :members:
   :undoc-members:
   :show-inheritance:

testing module
--------------

.. automodule:: xclim.testing
    :members:

subset module
-------------
.. warning::
    Subsetting is now offered via `clisops`. The functions offered by clisops
    will be described here once the subsetting functions API is made available.
    For now, refer to their documentation here:
    :doc:`clisops subset examples <clisops:notebooks/subset>`
